handcrank
=========

A very simple static site generator for converting `reStructredText
<http://docutils.sourceforge.net/rst.html>`_ into HTML5 and CSS3 formatted for
the desktop, tablet, and mobile browsers.

You got 2 minutes?
------------------

Install it::

    pip install handcrank

Create a new site::

    handcrank --sitedir ~/my_site startsite

Generate it::

    handcrank --sitedir ~/my_site generate

Open the site in a browser::

    open ~/my_site/output/index.html

That's it!

**See full documentation at** `http://packages.python.org/handcrank
<http://packages.python.org/handcrank>`_

What you can make
-----------------

.. image:: http://web.me.com/robmadole/handcrank/readme.png
